@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,12 +18,13 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from kde import ki18n, KAboutData
+from kde import KAboutData
+from mi18n import i18n
 
 from common import Internal
 
 
-class About(object):
+class About:
 
     """we need persistancy but do not want to spoil global name space"""
 
@@ -32,19 +33,19 @@ class About(object):
         catalog = ""
         homePage = "http://kde.org/applications/games/kajongg/"
         version = str(Internal.defaultPort)
-        programName = ki18n("Kajongg")
-        description = ki18n(
+        programName = i18n("Kajongg")
+        description = i18n(
             "Mah Jongg - the ancient Chinese board game for 4 players")
         kajongglicense = KAboutData.License_GPL
-        kajonggcopyright = ki18n("(C) 2008-2014 Wolfgang Rohdewald")
-        aboutText = ki18n("This is the classical Mah Jongg for four players. "
-                          "If you are looking for Mah Jongg solitaire please "
-                          "use the application kmahjongg.")
+        kajonggcopyright = "(C) 2008-2016 Wolfgang Rohdewald"
+        aboutText = i18n("This is the classical Mah Jongg for four players. "
+                         "If you are looking for Mah Jongg solitaire please "
+                         "use the application kmahjongg.")
 
         self.about = KAboutData(self.appName, catalog, programName,
                                 version, description, kajongglicense,
                                 kajonggcopyright, aboutText, homePage)
         self.about.addAuthor(
-            ki18n("Wolfgang Rohdewald"),
-            ki18n("Original author"),
+            "Wolfgang Rohdewald",
+            i18n("Original author"),
             "wolfgang@rohdewald.de")
