@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import weakref
 
-from common import Debug, unicodeString, StrMixin, nativeString
+from common import Debug, StrMixin, Internal
 from message import Message
 from wind import Wind
 from tile import Tile, TileList
@@ -35,7 +35,7 @@ class Move(StrMixin):
         if isinstance(command, Message):
             self.message = command
         else:
-            self.message = Message.defined[nativeString(command)]
+            self.message = Message.defined[command]
         self.table = None
         self.notifying = False
         self._player = weakref.ref(player) if player else None
@@ -45,29 +45,29 @@ class Move(StrMixin):
         self.score = None
         self.lastMeld = None
         for key, value in kwargs.items():
-            assert value != 'None'
+            assert not isinstance(value, bytes), 'value is bytes:{}'.format(repr(value))
             if value is None:
                 self.__setattr__(key, None)
-            elif key.lower().endswith('tile'):
-                self.__setattr__(key, Tile(nativeString(value)))
-            elif key.lower().endswith('tiles'):
-                self.__setattr__(key, TileList(nativeString(value)))
-            elif key.lower().endswith('meld'):
-                self.__setattr__(key, Meld(nativeString(value)))
-            elif key.lower().endswith('melds'):
-                self.__setattr__(key, MeldList(nativeString(value)))
-            elif key in ('wantedGame', 'score'):
-                self.__setattr__(key, nativeString(value))
-            elif key == 'playerNames':
-                self.__setattr__(key, self.convertWinds(value))
             else:
-                self.__setattr__(key, value)
+                if key.lower().endswith('tile'):
+                    self.__setattr__(key, Tile(value))
+                elif key.lower().endswith('tiles'):
+                    self.__setattr__(key, TileList(value))
+                elif key.lower().endswith('meld'):
+                    self.__setattr__(key, Meld(value))
+                elif key.lower().endswith('melds'):
+                    self.__setattr__(key, MeldList(value))
+                elif key == 'playerNames':
+                    if Internal.isServer:
+                        self.__setattr__(key, value)
+                    else:
+                        self.__setattr__(key, self.__convertWinds(value))
+                else:
+                    self.__setattr__(key, value)
 
     @staticmethod
-    def convertWinds(tuples):
+    def __convertWinds(tuples):
         """convert wind strings to Wind objects"""
-        if isinstance(tuples[0][0], Wind):
-            return tuples
         result = list()
         for wind, name in tuples:
             result.append(tuple([Wind(wind), name]))
@@ -82,7 +82,7 @@ class Move(StrMixin):
     @staticmethod
     def prettyKwargs(kwargs):
         """this is also used by the server, but the server does not use class Move"""
-        result = u''
+        result = ''
         for key in sorted(kwargs.keys()):
             value = kwargs[key]
             if key == 'token':
@@ -91,22 +91,22 @@ class Move(StrMixin):
                 oldValue = value
                 tuples = []
                 for oldTuple in oldValue:
-                    tuples.append(u''.join(unicodeString(x) for x in oldTuple))
-                value = u','.join(tuples)
+                    tuples.append(''.join(str(x) for x in oldTuple))
+                value = ','.join(tuples)
             if Debug.neutral and key == 'gameid':
-                result += u' gameid:GAMEID'
+                result += ' gameid:GAMEID'
             elif isinstance(value, bool) and value:
-                result += u' %s' % key
+                result += ' %s' % key
             elif isinstance(value, bool):
                 pass
             elif isinstance(value, bytes):
-                result += u' %s:%s' % (key, unicodeString(value))
+                result += ' %s:%s' % (key, value.decode())
             else:
-                result += u' %s:%s' % (key, value)
-        for old, new in ((u"('", u"("), (u"')", u")"), (u" '", u""),
-                         (u"',", u","), (u"[(", u"("), (u"])", u")")):
+                result += ' %s:%s' % (key, value)
+        for old, new in (("('", "("), ("')", ")"), (" '", ""),
+                         ("',", ","), ("[(", "("), ("])", ")")):
             result = result.replace(old, new)
         return result
 
-    def __unicode__(self):
-        return u'%s %s%s' % (self.player, self.message, Move.prettyKwargs(self.kwargs))
+    def __str__(self):
+        return '%s %s%s' % (self.player, self.message, Move.prettyKwargs(self.kwargs))
